package_query

Function package_query 

pub fn package_query(
    session: &Session,
    queries: Vec<&str>,
    options: Vec<QueryOption>,
    installed: bool,
) -> Result<Vec<Package>, Error>
Query packages.

Note

Set installed to true to query installed packages. The returned list will be sorted by package name.

Returns

A list of packages that match the query.

Errors

I/O errors will be returned if the apps/buckets directory is not readable.

A Regex error will be returned if the given query is not a valid regex.